@@ -5,7 +5,7 @@ from checkov.terraform.checks.resource.base_check import BaseResourceCheck
 class LaunchConfigurationEBSEncryption(BaseResourceCheck):
     def __init__(self):
         name = "Ensure all data stored in the Launch configuration EBS is securely encrypted "
-        id = "BC_AWS_EBS_1"
+        id = "CKV_AWS_8"
         supported_resources = ['aws_launch_configuration','aws_instance']
         categories = [CheckCategories.ENCRYPTION]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
@@ -21,12 +21,12 @@ class LaunchConfigurationEBSEncryption(BaseResourceCheck):
             if "block_device" in key and "ephemeral" not in key:
                 if "encrypted" in conf[key][0]:
                     if conf[key][0]["encrypted"] == [False]:
-                        return CheckResult.FAILURE
+                        return CheckResult.FAILED
                     else:
-                        return CheckResult.SUCCESS
+                        return CheckResult.PASSED
                 else:
-                    return CheckResult.FAILURE
-        return CheckResult.SUCCESS
+                    return CheckResult.FAILED
+        return CheckResult.PASSED
 
 
 check = LaunchConfigurationEBSEncryption()
