@@ -5,7 +5,7 @@ from checkov.terraform.checks.resource.base_check import BaseResourceCheck
 class S3Versioning(BaseResourceCheck):
     def __init__(self):
         name = "Ensure all data stored in the S3 bucket have versioning enabled"
-        id = "BC_AWS_S3_16"
+        id = "CKV_AWS_21"
         supported_resources = ['aws_s3_bucket']
         categories = [CheckCategories.BACKUP_AND_RECOVERY]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
@@ -20,8 +20,8 @@ class S3Versioning(BaseResourceCheck):
         if 'versioning' in conf.keys():
             versioning_block = conf['versioning'][0]
             if versioning_block['enabled'][0]:
-                return CheckResult.SUCCESS
-        return CheckResult.FAILURE
+                return CheckResult.PASSED
+        return CheckResult.FAILED
 
 
 scanner = S3Versioning()
