@@ -5,7 +5,7 @@ from checkov.terraform.checks.resource.base_check import BaseResourceCheck
 class StorageAccountsTransportEncryption(BaseResourceCheck):
     def __init__(self):
         name = "Ensure that 'Secure transfer required' is set to 'Enabled'"
-        id = "BC_AZURE_STORAGE_1"
+        id = "CKV_AZURE_3"
         supported_resources = ['azurerm_storage_account']
         categories = [CheckCategories.ENCRYPTION]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
@@ -20,8 +20,8 @@ class StorageAccountsTransportEncryption(BaseResourceCheck):
         if 'enable_https_traffic_only' in conf.keys():
             config = conf['enable_https_traffic_only'][0]
             if config:
-                return CheckResult.SUCCESS
-        return CheckResult.FAILURE
+                return CheckResult.PASSED
+        return CheckResult.FAILED
 
 
 check = StorageAccountsTransportEncryption()
