@@ -2,10 +2,10 @@ from enum import Enum
 
 
 class CheckResult(str, Enum):
-    SUCCESS = "SUCCESS"
-    FAILURE = "FAILURE"
+    PASSED = "PASSED"
+    FAILED = "FAILED"
     UNKNOWN = "UNKNOWN"
-    SUPPRESSED = "SUPPRESSED"
+    SKIPPED = "SKIPPED"
 
 
 class CheckCategories(Enum):
