@@ -1,5 +1,6 @@
 import logging
 import os
+from os import path
 
 import hcl2
 
@@ -9,6 +10,7 @@ class Parser():
 
     def hcl2(self, directory, tf_definitions={}, parsing_errors={}):
         modules_scan = []
+
         for file in os.listdir(directory):
             if file.endswith(".tf"):
                 tf_file = os.path.join(directory, file)
@@ -31,4 +33,17 @@ class Parser():
                         self.logger.debug('failed while parsing file %s' % tf_file, exc_info=e)
                         parsing_errors[tf_file] = e
         for m in modules_scan:
-            self.hcl2(directory=m, tf_definitions=tf_definitions)
+            if path.exists(m):
+                self.hcl2(directory=m, tf_definitions=tf_definitions)
+
+    def parse_file(self, file, tf_definitions={}, parsing_errors={}):
+        if file.endswith(".tf"):
+            try:
+                with(open(file, 'r')) as tf_file:
+                    tf_file.seek(0)
+                    dict = hcl2.load(tf_file)
+                    tf_defenition = dict
+                    tf_definitions[file] = tf_defenition
+            except Exception as e:
+                self.logger.debug('failed while parsing file %s' % file, exc_info=e)
+                parsing_errors[file] = e
